@@ -11,15 +11,17 @@ __all__ = [
     "Event",
     "EventType",
     "Watch",
+    "__version__"
 ]
 
 from . import exceptions, models
+from ._version import __version__
 from .client import K8sClient
 from .config import K8sConfig
 from .events import Event, EventType, Watch
+from .kube.resource_api import ResourceApi
 from .models.resource_item import CheckResult, ResourceItem
 from .models.resource_value import ResourceValue
-from .resource_api import ResourceApi
 
 cl: K8sClient
 
@@ -30,3 +32,4 @@ def __getattr__(name: str):
         cl = K8sClient()
         return cl
     raise AttributeError(name)
+
